open

Function open 

pub async fn open(
    path: &Path,
    lance: Option<&LanceArgs>,
) -> Result<Arc<dyn Dataset>>
Open a dataset at path, optionally checking out a specific Lance branch/version/tag. Returns an error if the dataset is not Lance and any LanceArgs field is set.