pub struct Uploader { /* private fields */ }Expand description
Manage all uploading information; handle uplaoding and resuming. However, this struct does not include a copy of raw file or chunks. They shoud be either borrowed from the current transaction or import from a file path (such as resuming).
Implementations
Sourceimpl Uploader
impl Uploader
Sourcepub fn uploader_json(&self) -> String
pub fn uploader_json(&self) -> String
Save the uploader information as a json string. The saved data can be later used for resuming the uploading.
Sourcepub fn resume(uploader_json: &str) -> Self
pub fn resume(uploader_json: &str) -> Self
Resume an uploading by input a saved uploader json information.
pub fn current_idx(&self) -> usize
pub fn chunk_size(&self) -> usize
pub fn verify_uploader(&self, chunks: &Chunks) -> bool