pub trait LanceCapabilities: Send + Sync {
// Required methods
fn list_versions<'life0, 'life1, 'async_trait>(
&'life0 self,
branch: Option<&'life1 str>,
tagged_only: bool,
) -> Pin<Box<dyn Future<Output = Result<Vec<VersionInfo>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn list_branches<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<BranchInfo>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn list_indices<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<IndexInfo>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn list_tags<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TagInfo>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Lance-specific operations exposed beyond the format-agnostic Dataset trait.
Required Methods
Sourcefn list_versions<'life0, 'life1, 'async_trait>(
&'life0 self,
branch: Option<&'life1 str>,
tagged_only: bool,
) -> Pin<Box<dyn Future<Output = Result<Vec<VersionInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn list_versions<'life0, 'life1, 'async_trait>(
&'life0 self,
branch: Option<&'life1 str>,
tagged_only: bool,
) -> Pin<Box<dyn Future<Output = Result<Vec<VersionInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
List versions on branch (defaults to main when None). When
tagged_only is true, drops untagged versions from the result.
Sourcefn list_branches<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<BranchInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_branches<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<BranchInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List every branch the dataset has, including the default main.
Sourcefn list_indices<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<IndexInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_indices<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<IndexInfo>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List indices defined on the active version of the dataset.
List every tag in the dataset, regardless of branch.